@@ -2,7 +2,7 @@
 # PODNAME: Test::Rail::Parser
 
 package Test::Rail::Parser;
-$Test::Rail::Parser::VERSION = '0.040';
+$Test::Rail::Parser::VERSION = '0.041';
 use strict;
 use warnings;
 use utf8;
@@ -28,7 +28,8 @@ sub new {
         'comment' => \&commentCallback,
         'unknown' => \&unknownCallback,
         'bailout' => \&bailoutCallback,
-        'EOF'     => \&EOFCallback
+        'EOF'     => \&EOFCallback,
+        'plan'    => \&planCallback,
     };
 
     my $tropts = {
@@ -52,7 +53,8 @@ sub new {
 
         #Stubs for extension by subclassers
         'result_options'        => delete $opts->{'result_options'},
-        'result_custom_options' => delete $opts->{'result_custom_options'}
+        'result_custom_options' => delete $opts->{'result_custom_options'},
+        'test_bad_status'       => delete $opts->{'test_bad_status'},
     };
 
     confess("plan passed, but no run passed!")
@@ -95,6 +97,11 @@ sub new {
     my @todof = grep { $_->{'name'} eq 'todo_fail' } @{ $tropts->{'statuses'} };
     my @todop = grep { $_->{'name'} eq 'todo_pass' } @{ $tropts->{'statuses'} };
     my @retest = grep { $_->{'name'} eq 'retest' } @{ $tropts->{'statuses'} };
+    my @tbad;
+    @tbad =
+      grep { $_->{'name'} eq $tropts->{test_bad_status} }
+      @{ $tropts->{'statuses'} }
+      if $tropts->{test_bad_status};
     confess("No status with internal name 'passed' in TestRail!")
       unless scalar(@ok);
     confess("No status with internal name 'failed' in TestRail!")
@@ -107,6 +114,9 @@ sub new {
       unless scalar(@todop);
     confess("No status with internal name 'retest' in TestRail!")
       unless scalar(@retest);
+    confess(
+        "No status with internal name '$tropts->{test_bad_status}' in TestRail!"
+    ) unless scalar(@tbad) || !$tropts->{test_bad_status};
 
     #Map in all the statuses
     foreach my $status ( @{ $tropts->{'statuses'} } ) {
@@ -534,8 +544,13 @@ sub EOFCallback {
     my $status      = $self->{'tr_opts'}->{'ok'}->{'id'};
     my $todo_failed = $self->todo() - $self->todo_passed();
     $status = $self->{'tr_opts'}->{'not_ok'}->{'id'} if $self->has_problems();
-    $status = $self->{'tr_opts'}->{'retest'}->{'id'}
-      if !$self->tests_run();    #No tests were run, env fail
+    if (   !$self->tests_run()
+        && !$self->is_good_plan()
+        && $self->{'tr_opts'}->{test_bad_status} )
+    {  #No tests were run, no plan, code is probably bad so allow custom marking
+        $status =
+          $self->{'tr_opts'}->{ $self->{'tr_opts'}->{test_bad_status} }->{'id'};
+    }
     $status = $self->{'tr_opts'}->{'todo_pass'}->{'id'}
       if $self->todo_passed()
       && !$self->failed()
@@ -596,6 +611,12 @@ sub EOFCallback {
     return $cres;
 }
 
+sub planCallback {
+    my ($plan) = @_;
+    my $self = $plan->{'parser'};
+    $self->{raw_output} .= $plan->as_string;
+}
+
 sub _set_result {
     my ( $self, $run_id, $test_name, $status, $notes, $options,
         $custom_options ) = @_;
@@ -720,7 +741,7 @@ Test::Rail::Parser - Upload your TAP results to TestRail
 
 =head1 VERSION
 
-version 0.040
+version 0.041
 
 =head1 DESCRIPTION
 
@@ -776,10 +797,12 @@ Get the TAP Parser ready to talk to TestRail, and register a bunch of callbacks
 
 =item B<sections> - ARRAYREF (optional): Restrict a spawned run to cases in these particular sections.
 
-=item B<autoclose> - BOOLEAN (optional): If no cases in the run/plan are marked 'untested' or 'retest', go ahead and close the run.  Default false.
+=item B<autoclose> - BOOLEAN (optional): If no cases in the run/plan are marked 'Untested' or 'Retest', go ahead and close the run.  Default false.
 
 =item B<encoding> - STRING (optional): Character encoding of TAP to be parsed and the various inputs parameters for the parser.  Defaults to UTF-8, see L<Encode::Supported> for a list of supported encodings.
 
+=item B<test_bad_status> - STRING (optional): 'internal' name of whatever status you want to mark compile failures & no plan + no assertion tests.
+
 =back
 
 =back
@@ -790,14 +813,16 @@ This module also attempts to calculate the elapsed time to run each test if it i
 
 The constructor will terminate if the statuses 'pass', 'fail', 'retest', 'skip', 'todo_pass', and 'todo_fail' are not registered as result internal names in your TestRail install.
 
+The purpose of the retest status is somewhat special, as there is no way to set a test back to 'untested' in TestRail, and we use this to allow automation to pick back up if
+something needs re-work for whatever reason.
+
 The global status of the case will be set according to the following rules:
 
     1. If there are no issues whatsoever besides TODO failing tests & skips, mark as PASS
     2. If there are any non-skipped or TODOed fails OR a bad plan (extra/missing tests), mark as FAIL
     3. If there are only SKIPs (e.g. plan => skip_all), mark as SKIP
     4. If the only issues with the test are TODO tests that pass, mark as TODO PASS (to denote these TODOs for removal).
-    5. If no tests are run at all, mark as 'retest'.  This is making the assumption that such failures are due to test environment being setup improperly;
-       which can be remediated and retested.
+    5. If no tests are run at all, and no plan made (such as a compile failure), the cases will be marked as failures unless you provide a test_bad status name in your testrailrc.
 
 Step results will always be whatever status is relevant to the particular step.
 
@@ -846,6 +871,10 @@ If bail_out is called, note it and add step results.
 If we are running in step_results mode, send over all the step results to TestRail.
 Otherwise, upload the overall results of the test to TestRail.
 
+=head2 planCallback
+
+Used to record test planning messages.
+
 =head2 make_result
 
 make_result has been overridden to make the parser object available to callbacks.
